#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-CgnPxnC5z2MLhiHgoRaBIQ
key:                  coinbase-pro-0.9.3.2-CgnPxnC5z2MLhiHgoRaBIQ
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  a220745a573e67c56de0ffca856161c4
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-CgnPxnC5z2MLhiHgoRaBIQ
depends:
    HsOpenSSL-0.11.7.9-Ek0WvIsZyHy3lOVt2hjCyN
    aeson-2.2.1.0-HnfSu9AKfZzFhPBHWndcTt
    aeson-casing-0.2.0.0-IKxfKFGoBLvFCmJb7CwrO2
    async-2.2.5-B3LTRS5ADZ11aNLUYaUoKB base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-8vn7VwZsEErCDwQm4O5d9O exceptions-0.10.7
    http-api-data-0.6.1-3JOLDyzPsEaChqTLMvm2N0
    http-client-0.7.19-EVmHbVjkohhiJgPWVdNtw
    http-client-tls-0.3.6.4-GDksyJ5Nzq117qoaBKOr4F
    http-streams-0.8.9.9-D6q2JqBHs1o4aw5Crq17iZ
    http-types-0.12.4-LRx8vzb7Bf1JlNkRF4x5ME
    io-streams-1.5.2.2-JAPzGEMCS1ZBppLVOv1qNP
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-KfjlNjVlGG85uIUjnrRE8N
    servant-0.20.3.0-HkzCbydiSQ34G1uhEnqzuH
    servant-client-0.20.3.0-HOyr7kOaz7yJV3iJ0nU5j3
    servant-client-core-0.20.3.0-70z2hWiBcGFJeyavbMOs07
    tasty-1.5.2-HZ7OH7KqnUfCFCBNtP1fQc
    tasty-hunit-0.10.2-3ZgnvvferpX7oIIst0I4Ng text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-BNVLsLUbLpFJjp2TsNDFl0
    unordered-containers-0.2.20.1-50KuqheKibtHrVzrLcPiuM
    uuid-1.3.16-BxsDsyUzPb34doh5lAthbA
    vector-0.13.2.0-5YxFBFTVtOB5p4D1EBw8Kb
    websockets-0.12.7.3-1fpQTlZJlBhJaDcrukAhWZ
    wuss-2.0.1.6-9cJPzDWAQrQ2c79sPKFoIL

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

